=============================
Joints Framework (Docstrings)
=============================

Joint (Docstrings)
==================

.. module:: sympy.physics.mechanics.joint

Joint
-----

.. autoclass:: Joint
   :members:

PinJoint
--------

.. autoclass:: PinJoint
   :members:

PrismaticJoint
--------------

.. autoclass:: PrismaticJoint
   :members:

JointsMethod (Docstring)
========================

.. automodule:: sympy.physics.mechanics.jointsmethod
   :members:
